const GObject = imports.gi.GObject;
const Gio = imports.gi.Gio;
const Gtk = imports.gi.Gtk;
const GTK_MAJOR_VERSION = Gtk.get_major_version();
const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();

function init() {}

const ServerPrefsWidget = new GObject.registerClass(
    class ExtensionMumblePingPrefsWidget extends Gtk.Frame {
        _setMargin(widget, numPixels) {
            if (GTK_MAJOR_VERSION >= 4) {
                widget.set_margin_start(numPixels);
                widget.set_margin_end(numPixels);
            } else {
                widget.set_margin_left(numPixels);
                widget.set_margin_right(numPixels);
            }
            widget.set_margin_top(numPixels);
            widget.set_margin_bottom(numPixels);
        }

        _init() {
            super._init();

            //////////////////////////////////////////////////////////////////////////
            // Create a Grid layout
            const grid = new Gtk.Grid();
            grid.set_column_spacing(10);
            grid.set_row_spacing(10);
            this._setMargin(this, 10);
            this._setMargin(grid, 10);
            if (GTK_MAJOR_VERSION >= 4)
                this.set_child(grid);
            else
                this.add(grid);
            // End
            //////////////////////////////////////////////////////////////////////////

            this._settings = ExtensionUtils.getSettings('org.gnome.shell.extensions.Server');
            
            //////////////////////////////////////////////////////////////////////////
            // Create a label & entry for Server IP
            const IpLabel = new Gtk.Label({
                label: 'Server IP:',
                halign: Gtk.Align.START,
                visible: true
            });
            grid.attach(IpLabel, 0, 0, 1, 1);

            const IpEntry = Gtk.Entry.new()
            grid.attach(IpEntry, 1, 0, 1, 1);

            this._settings.bind(
                'serverip',
                IpEntry,
                'text',
                Gio.SettingsBindFlags.DEFAULT
            );
            // End
            //////////////////////////////////////////////////////////////////////////

            //////////////////////////////////////////////////////////////////////////
            // Create a label & entry for Server MAC
            const MacLabel = new Gtk.Label({
                label: 'Server MAC:',
                halign: Gtk.Align.START,
                visible: true
            });
            grid.attach(MacLabel, 0, 1, 1, 1);

            const MacEntry = Gtk.Entry.new()
            grid.attach(MacEntry, 1, 1, 1, 1);

            this._settings.bind(
                'servermac',
                MacEntry,
                'text',
                Gio.SettingsBindFlags.DEFAULT
            );
            // End
            //////////////////////////////////////////////////////////////////////////


            //////////////////////////////////////////////////////////////////////////
            // Create a label & entry for polling
            const PollLabel = new Gtk.Label({
                label: 'Server Poll:',
                halign: Gtk.Align.START,
                visible: true
            });
            grid.attach(PollLabel, 0, 2, 1, 1);

            const PollSpinButton = Gtk.SpinButton.new_with_range(
                5,
                300,
                5
            );
            // let PollEntry = Gtk.Entry.new()
            grid.attach(PollSpinButton, 1, 2, 1, 1);

            this._settings.bind(
                'serverpoll',
                PollSpinButton,
                'value',
                Gio.SettingsBindFlags.DEFAULT
            );
            // End
            //////////////////////////////////////////////////////////////////////////


            //////////////////////////////////////////////////////////////////////////
            // Create a label & switch for debugging
            const DebugLabel = new Gtk.Label({
                label: 'Debug Extension:',
                halign: Gtk.Align.START,
                visible: true
            });
            grid.attach(DebugLabel, 0, 3, 1, 1);

            const DebugSwitch = new Gtk.Switch()
            const DebugModeHbox = Gtk.Box.new(Gtk.Orientation.HORIZONTAL, 0);
            if (GTK_MAJOR_VERSION >= 4)
                DebugModeHbox.append(DebugSwitch);
            else
                DebugModeHbox.add(DebugSwitch);
            grid.attach(DebugModeHbox, 1, 3, 1, 1);

            this._settings.bind(
                'serverdebug',
                DebugSwitch,
                'active',
                Gio.SettingsBindFlags.DEFAULT
            );
            // End
            //////////////////////////////////////////////////////////////////////////
        }

    });

function buildPrefsWidget() {
    const prefsWidget = new ServerPrefsWidget();
    // Return our widget which will be added to the window
    return prefsWidget;
}
